# Orcasound HLS utilities

This simple package is a collection of useful utilities needed for streaming/downloading of HLS audio from Orcasound AWS buckets.

`HLSStream` class is being used for continuous streaming and `DateRangeHLSStream` class is being used to get data in the specified time range.
